django-slack
============

**Consulting services**: if your organisation needs a reputable software developer with a track record of producing high-quality and maintainable Python/Django code, please get in touch to discuss your needs. `More info <https://chris-lamb.co.uk/services>`_

----

* Docs: https://django-slack.readthedocs.org/
* Homepage: https://chris-lamb.co.uk/projects/django-slack
